"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.repositoryReducer = exports.isResourceAction = void 0;

var _repository = require("./repository");

var _resource = require("./resource");

var T = _interopRequireWildcard(require("./types"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

/**
 * Check if the action type relates to the named resource and should be handled by the reducer of
 * this package.
 *
 * @param {string} resourceName
 * @param {Object} action
 * @returns {boolean}
 */
var isResourceAction = function isResourceAction(resourceName, action) {
  return !!(action.payload && action.payload.resourceName && action.payload.resourceName === resourceName && T.ARRAY.indexOf(action.type) >= 0);
};
/**
 * Function consuming repository and action objects and returning updated repository object. If the
 * action passes `isResourceAction()` test, your own reducer should delegate the action handling to
 * this function.
 *
 * @param {Object} repository
 * @param {Object} action
 * @returns {Object} Updated repository.
 */


exports.isResourceAction = isResourceAction;

var repositoryReducer = function repositoryReducer(repository, action) {
  switch (action.type) {
    case T.FETCH_RESOURCE_FAILED:
      return (0, _repository.pushResource)(repository, (0, _resource.createFailed)(action.payload.id, action.payload.error));

    case T.FETCH_RESOURCE_RECEIVED:
      return (0, _repository.pushResource)(repository, (0, _resource.createReceived)(action.payload.id, action.payload.data));

    case T.FETCH_RESOURCE_REQUESTED:
      return (0, _repository.pushResource)(repository, (0, _resource.createRequested)(action.payload.id));

    default:
      return repository;
  }
};

exports.repositoryReducer = repositoryReducer;